"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import data_room_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class DataRoomStatus(_DataRoomStatus, metaclass=_DataRoomStatusEnumTypeWrapper):
    pass
class _DataRoomStatus:
    V = typing.NewType('V', builtins.int)
class _DataRoomStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DataRoomStatus.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    Active = DataRoomStatus.V(0)
    Stopped = DataRoomStatus.V(1)

Active = DataRoomStatus.V(0)
Stopped = DataRoomStatus.V(1)
global___DataRoomStatus = DataRoomStatus


class GcgRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    EXECUTECOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    CREATEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSREQUEST_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETREQUEST_FIELD_NUMBER: builtins.int
    JOBSTATUSREQUEST_FIELD_NUMBER: builtins.int
    GETRESULTSREQUEST_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    EXECUTEDEVELOPMENTCOMPUTEREQUEST_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATUREREQUEST_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMCONFIGURATIONHISTORYREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSREQUEST_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITREQUEST_FIELD_NUMBER: builtins.int
    @property
    def executeComputeRequest(self) -> global___ExecuteComputeRequest: ...
    @property
    def createDataRoomRequest(self) -> global___CreateDataRoomRequest: ...
    @property
    def publishDatasetToDataRoomRequest(self) -> global___PublishDatasetToDataRoomRequest: ...
    @property
    def retrieveDataRoomRequest(self) -> global___RetrieveDataRoomRequest: ...
    @property
    def retrieveAuditLogRequest(self) -> global___RetrieveAuditLogRequest: ...
    @property
    def retrieveDataRoomStatusRequest(self) -> global___RetrieveDataRoomStatusRequest: ...
    @property
    def updateDataRoomStatusRequest(self) -> global___UpdateDataRoomStatusRequest: ...
    @property
    def retrievePublishedDatasetsRequest(self) -> global___RetrievePublishedDatasetsRequest: ...
    @property
    def removePublishedDatasetRequest(self) -> global___RemovePublishedDatasetRequest: ...
    @property
    def jobStatusRequest(self) -> global___JobStatusRequest: ...
    @property
    def getResultsRequest(self) -> global___GetResultsRequest: ...
    @property
    def createConfigurationCommitRequest(self) -> global___CreateConfigurationCommitRequest: ...
    @property
    def executeDevelopmentComputeRequest(self) -> global___ExecuteDevelopmentComputeRequest: ...
    @property
    def generateMergeApprovalSignatureRequest(self) -> global___GenerateMergeApprovalSignatureRequest: ...
    @property
    def mergeConfigurationCommitRequest(self) -> global___MergeConfigurationCommitRequest: ...
    @property
    def retrieveDataRoomConfigurationHistoryRequest(self) -> global___RetrieveDataRoomConfigurationHistoryRequest: ...
    @property
    def retrieveConfigurationCommitApproversRequest(self) -> global___RetrieveConfigurationCommitApproversRequest: ...
    @property
    def retrieveConfigurationCommitRequest(self) -> global___RetrieveConfigurationCommitRequest: ...
    def __init__(self,
        *,
        executeComputeRequest : typing.Optional[global___ExecuteComputeRequest] = ...,
        createDataRoomRequest : typing.Optional[global___CreateDataRoomRequest] = ...,
        publishDatasetToDataRoomRequest : typing.Optional[global___PublishDatasetToDataRoomRequest] = ...,
        retrieveDataRoomRequest : typing.Optional[global___RetrieveDataRoomRequest] = ...,
        retrieveAuditLogRequest : typing.Optional[global___RetrieveAuditLogRequest] = ...,
        retrieveDataRoomStatusRequest : typing.Optional[global___RetrieveDataRoomStatusRequest] = ...,
        updateDataRoomStatusRequest : typing.Optional[global___UpdateDataRoomStatusRequest] = ...,
        retrievePublishedDatasetsRequest : typing.Optional[global___RetrievePublishedDatasetsRequest] = ...,
        removePublishedDatasetRequest : typing.Optional[global___RemovePublishedDatasetRequest] = ...,
        jobStatusRequest : typing.Optional[global___JobStatusRequest] = ...,
        getResultsRequest : typing.Optional[global___GetResultsRequest] = ...,
        createConfigurationCommitRequest : typing.Optional[global___CreateConfigurationCommitRequest] = ...,
        executeDevelopmentComputeRequest : typing.Optional[global___ExecuteDevelopmentComputeRequest] = ...,
        generateMergeApprovalSignatureRequest : typing.Optional[global___GenerateMergeApprovalSignatureRequest] = ...,
        mergeConfigurationCommitRequest : typing.Optional[global___MergeConfigurationCommitRequest] = ...,
        retrieveDataRoomConfigurationHistoryRequest : typing.Optional[global___RetrieveDataRoomConfigurationHistoryRequest] = ...,
        retrieveConfigurationCommitApproversRequest : typing.Optional[global___RetrieveConfigurationCommitApproversRequest] = ...,
        retrieveConfigurationCommitRequest : typing.Optional[global___RetrieveConfigurationCommitRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitRequest",b"createConfigurationCommitRequest",u"createDataRoomRequest",b"createDataRoomRequest",u"executeComputeRequest",b"executeComputeRequest",u"executeDevelopmentComputeRequest",b"executeDevelopmentComputeRequest",u"gcg_request",b"gcg_request",u"generateMergeApprovalSignatureRequest",b"generateMergeApprovalSignatureRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"mergeConfigurationCommitRequest",b"mergeConfigurationCommitRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveConfigurationCommitApproversRequest",b"retrieveConfigurationCommitApproversRequest",u"retrieveConfigurationCommitRequest",b"retrieveConfigurationCommitRequest",u"retrieveDataRoomConfigurationHistoryRequest",b"retrieveDataRoomConfigurationHistoryRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetsRequest",b"retrievePublishedDatasetsRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitRequest",b"createConfigurationCommitRequest",u"createDataRoomRequest",b"createDataRoomRequest",u"executeComputeRequest",b"executeComputeRequest",u"executeDevelopmentComputeRequest",b"executeDevelopmentComputeRequest",u"gcg_request",b"gcg_request",u"generateMergeApprovalSignatureRequest",b"generateMergeApprovalSignatureRequest",u"getResultsRequest",b"getResultsRequest",u"jobStatusRequest",b"jobStatusRequest",u"mergeConfigurationCommitRequest",b"mergeConfigurationCommitRequest",u"publishDatasetToDataRoomRequest",b"publishDatasetToDataRoomRequest",u"removePublishedDatasetRequest",b"removePublishedDatasetRequest",u"retrieveAuditLogRequest",b"retrieveAuditLogRequest",u"retrieveConfigurationCommitApproversRequest",b"retrieveConfigurationCommitApproversRequest",u"retrieveConfigurationCommitRequest",b"retrieveConfigurationCommitRequest",u"retrieveDataRoomConfigurationHistoryRequest",b"retrieveDataRoomConfigurationHistoryRequest",u"retrieveDataRoomRequest",b"retrieveDataRoomRequest",u"retrieveDataRoomStatusRequest",b"retrieveDataRoomStatusRequest",u"retrievePublishedDatasetsRequest",b"retrievePublishedDatasetsRequest",u"updateDataRoomStatusRequest",b"updateDataRoomStatusRequest"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"gcg_request",b"gcg_request"]) -> typing.Optional[typing_extensions.Literal["executeComputeRequest","createDataRoomRequest","publishDatasetToDataRoomRequest","retrieveDataRoomRequest","retrieveAuditLogRequest","retrieveDataRoomStatusRequest","updateDataRoomStatusRequest","retrievePublishedDatasetsRequest","removePublishedDatasetRequest","jobStatusRequest","getResultsRequest","createConfigurationCommitRequest","executeDevelopmentComputeRequest","generateMergeApprovalSignatureRequest","mergeConfigurationCommitRequest","retrieveDataRoomConfigurationHistoryRequest","retrieveConfigurationCommitApproversRequest","retrieveConfigurationCommitRequest"]]: ...
global___GcgRequest = GcgRequest

class GcgResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FAILURE_FIELD_NUMBER: builtins.int
    EXECUTECOMPUTERESPONSE_FIELD_NUMBER: builtins.int
    CREATEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    PUBLISHDATASETTODATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEAUDITLOGRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    UPDATEDATAROOMSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEPUBLISHEDDATASETSRESPONSE_FIELD_NUMBER: builtins.int
    REMOVEPUBLISHEDDATASETRESPONSE_FIELD_NUMBER: builtins.int
    JOBSTATUSRESPONSE_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSECHUNK_FIELD_NUMBER: builtins.int
    GETRESULTSRESPONSEFOOTER_FIELD_NUMBER: builtins.int
    CREATECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    GENERATEMERGEAPPROVALSIGNATURERESPONSE_FIELD_NUMBER: builtins.int
    MERGECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVEDATAROOMCONFIGURATIONHISTORYRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITAPPROVERSRESPONSE_FIELD_NUMBER: builtins.int
    RETRIEVECONFIGURATIONCOMMITRESPONSE_FIELD_NUMBER: builtins.int
    failure: typing.Text = ...
    @property
    def executeComputeResponse(self) -> global___ExecuteComputeResponse: ...
    @property
    def createDataRoomResponse(self) -> global___CreateDataRoomResponse: ...
    @property
    def publishDatasetToDataRoomResponse(self) -> global___PublishDatasetToDataRoomResponse: ...
    @property
    def retrieveDataRoomResponse(self) -> global___RetrieveDataRoomResponse: ...
    @property
    def retrieveAuditLogResponse(self) -> global___RetrieveAuditLogResponse: ...
    @property
    def retrieveDataRoomStatusResponse(self) -> global___RetrieveDataRoomStatusResponse: ...
    @property
    def updateDataRoomStatusResponse(self) -> global___UpdateDataRoomStatusResponse: ...
    @property
    def retrievePublishedDatasetsResponse(self) -> global___RetrievePublishedDatasetsResponse: ...
    @property
    def removePublishedDatasetResponse(self) -> global___RemovePublishedDatasetResponse: ...
    @property
    def jobStatusResponse(self) -> global___JobStatusResponse: ...
    @property
    def getResultsResponseChunk(self) -> global___GetResultsResponseChunk: ...
    @property
    def getResultsResponseFooter(self) -> global___GetResultsResponseFooter: ...
    @property
    def createConfigurationCommitResponse(self) -> global___CreateConfigurationCommitResponse: ...
    @property
    def generateMergeApprovalSignatureResponse(self) -> global___GenerateMergeApprovalSignatureResponse: ...
    @property
    def mergeConfigurationCommitResponse(self) -> global___MergeConfigurationCommitResponse: ...
    @property
    def retrieveDataRoomConfigurationHistoryResponse(self) -> global___RetrieveDataRoomConfigurationHistoryResponse: ...
    @property
    def retrieveConfigurationCommitApproversResponse(self) -> global___RetrieveConfigurationCommitApproversResponse: ...
    @property
    def retrieveConfigurationCommitResponse(self) -> global___RetrieveConfigurationCommitResponse: ...
    def __init__(self,
        *,
        failure : typing.Text = ...,
        executeComputeResponse : typing.Optional[global___ExecuteComputeResponse] = ...,
        createDataRoomResponse : typing.Optional[global___CreateDataRoomResponse] = ...,
        publishDatasetToDataRoomResponse : typing.Optional[global___PublishDatasetToDataRoomResponse] = ...,
        retrieveDataRoomResponse : typing.Optional[global___RetrieveDataRoomResponse] = ...,
        retrieveAuditLogResponse : typing.Optional[global___RetrieveAuditLogResponse] = ...,
        retrieveDataRoomStatusResponse : typing.Optional[global___RetrieveDataRoomStatusResponse] = ...,
        updateDataRoomStatusResponse : typing.Optional[global___UpdateDataRoomStatusResponse] = ...,
        retrievePublishedDatasetsResponse : typing.Optional[global___RetrievePublishedDatasetsResponse] = ...,
        removePublishedDatasetResponse : typing.Optional[global___RemovePublishedDatasetResponse] = ...,
        jobStatusResponse : typing.Optional[global___JobStatusResponse] = ...,
        getResultsResponseChunk : typing.Optional[global___GetResultsResponseChunk] = ...,
        getResultsResponseFooter : typing.Optional[global___GetResultsResponseFooter] = ...,
        createConfigurationCommitResponse : typing.Optional[global___CreateConfigurationCommitResponse] = ...,
        generateMergeApprovalSignatureResponse : typing.Optional[global___GenerateMergeApprovalSignatureResponse] = ...,
        mergeConfigurationCommitResponse : typing.Optional[global___MergeConfigurationCommitResponse] = ...,
        retrieveDataRoomConfigurationHistoryResponse : typing.Optional[global___RetrieveDataRoomConfigurationHistoryResponse] = ...,
        retrieveConfigurationCommitApproversResponse : typing.Optional[global___RetrieveConfigurationCommitApproversResponse] = ...,
        retrieveConfigurationCommitResponse : typing.Optional[global___RetrieveConfigurationCommitResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitResponse",b"createConfigurationCommitResponse",u"createDataRoomResponse",b"createDataRoomResponse",u"executeComputeResponse",b"executeComputeResponse",u"failure",b"failure",u"gcg_response",b"gcg_response",u"generateMergeApprovalSignatureResponse",b"generateMergeApprovalSignatureResponse",u"getResultsResponseChunk",b"getResultsResponseChunk",u"getResultsResponseFooter",b"getResultsResponseFooter",u"jobStatusResponse",b"jobStatusResponse",u"mergeConfigurationCommitResponse",b"mergeConfigurationCommitResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveConfigurationCommitApproversResponse",b"retrieveConfigurationCommitApproversResponse",u"retrieveConfigurationCommitResponse",b"retrieveConfigurationCommitResponse",u"retrieveDataRoomConfigurationHistoryResponse",b"retrieveDataRoomConfigurationHistoryResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetsResponse",b"retrievePublishedDatasetsResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"createConfigurationCommitResponse",b"createConfigurationCommitResponse",u"createDataRoomResponse",b"createDataRoomResponse",u"executeComputeResponse",b"executeComputeResponse",u"failure",b"failure",u"gcg_response",b"gcg_response",u"generateMergeApprovalSignatureResponse",b"generateMergeApprovalSignatureResponse",u"getResultsResponseChunk",b"getResultsResponseChunk",u"getResultsResponseFooter",b"getResultsResponseFooter",u"jobStatusResponse",b"jobStatusResponse",u"mergeConfigurationCommitResponse",b"mergeConfigurationCommitResponse",u"publishDatasetToDataRoomResponse",b"publishDatasetToDataRoomResponse",u"removePublishedDatasetResponse",b"removePublishedDatasetResponse",u"retrieveAuditLogResponse",b"retrieveAuditLogResponse",u"retrieveConfigurationCommitApproversResponse",b"retrieveConfigurationCommitApproversResponse",u"retrieveConfigurationCommitResponse",b"retrieveConfigurationCommitResponse",u"retrieveDataRoomConfigurationHistoryResponse",b"retrieveDataRoomConfigurationHistoryResponse",u"retrieveDataRoomResponse",b"retrieveDataRoomResponse",u"retrieveDataRoomStatusResponse",b"retrieveDataRoomStatusResponse",u"retrievePublishedDatasetsResponse",b"retrievePublishedDatasetsResponse",u"updateDataRoomStatusResponse",b"updateDataRoomStatusResponse"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"gcg_response",b"gcg_response"]) -> typing.Optional[typing_extensions.Literal["failure","executeComputeResponse","createDataRoomResponse","publishDatasetToDataRoomResponse","retrieveDataRoomResponse","retrieveAuditLogResponse","retrieveDataRoomStatusResponse","updateDataRoomStatusResponse","retrievePublishedDatasetsResponse","removePublishedDatasetResponse","jobStatusResponse","getResultsResponseChunk","getResultsResponseFooter","createConfigurationCommitResponse","generateMergeApprovalSignatureResponse","mergeConfigurationCommitResponse","retrieveDataRoomConfigurationHistoryResponse","retrieveConfigurationCommitApproversResponse","retrieveConfigurationCommitResponse"]]: ...
global___GcgResponse = GcgResponse

class CreateDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int
    INITIALCONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    @property
    def initialConfiguration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[data_room_pb2.ConfigurationModification]: ...
    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        initialConfiguration : typing.Optional[typing.Iterable[data_room_pb2.ConfigurationModification]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom",u"initialConfiguration",b"initialConfiguration"]) -> None: ...
global___CreateDataRoomRequest = CreateDataRoomRequest

class CreateDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    DATAROOMVALIDATIONERROR_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    @property
    def dataRoomValidationError(self) -> global___DataRoomValidationError: ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        dataRoomValidationError : typing.Optional[global___DataRoomValidationError] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomId",b"dataRoomId",u"dataRoomValidationError",b"dataRoomValidationError"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response",u"dataRoomId",b"dataRoomId",u"dataRoomValidationError",b"dataRoomValidationError"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"create_data_room_response",b"create_data_room_response"]) -> typing.Optional[typing_extensions.Literal["dataRoomId","dataRoomValidationError"]]: ...
global___CreateDataRoomResponse = CreateDataRoomResponse

class DataRoomValidationError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MESSAGE_FIELD_NUMBER: builtins.int
    PERMISSIONINDEX_FIELD_NUMBER: builtins.int
    COMPUTENODEID_FIELD_NUMBER: builtins.int
    USERPERMISSIONID_FIELD_NUMBER: builtins.int
    ATTESTATIONSPECIFICATIONID_FIELD_NUMBER: builtins.int
    AUTHENTICATIONMETHODID_FIELD_NUMBER: builtins.int
    message: typing.Text = ...
    permissionIndex: builtins.int = ...
    computeNodeId: typing.Text = ...
    userPermissionId: typing.Text = ...
    attestationSpecificationId: typing.Text = ...
    authenticationMethodId: typing.Text = ...
    def __init__(self,
        *,
        message : typing.Text = ...,
        permissionIndex : builtins.int = ...,
        computeNodeId : typing.Text = ...,
        userPermissionId : typing.Text = ...,
        attestationSpecificationId : typing.Text = ...,
        authenticationMethodId : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId",u"_authenticationMethodId",b"_authenticationMethodId",u"_computeNodeId",b"_computeNodeId",u"_permissionIndex",b"_permissionIndex",u"_userPermissionId",b"_userPermissionId",u"attestationSpecificationId",b"attestationSpecificationId",u"authenticationMethodId",b"authenticationMethodId",u"computeNodeId",b"computeNodeId",u"permissionIndex",b"permissionIndex",u"userPermissionId",b"userPermissionId"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId",u"_authenticationMethodId",b"_authenticationMethodId",u"_computeNodeId",b"_computeNodeId",u"_permissionIndex",b"_permissionIndex",u"_userPermissionId",b"_userPermissionId",u"attestationSpecificationId",b"attestationSpecificationId",u"authenticationMethodId",b"authenticationMethodId",u"computeNodeId",b"computeNodeId",u"message",b"message",u"permissionIndex",b"permissionIndex",u"userPermissionId",b"userPermissionId"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_attestationSpecificationId",b"_attestationSpecificationId"]) -> typing.Optional[typing_extensions.Literal["attestationSpecificationId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_authenticationMethodId",b"_authenticationMethodId"]) -> typing.Optional[typing_extensions.Literal["authenticationMethodId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_computeNodeId",b"_computeNodeId"]) -> typing.Optional[typing_extensions.Literal["computeNodeId"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_permissionIndex",b"_permissionIndex"]) -> typing.Optional[typing_extensions.Literal["permissionIndex"]]: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"_userPermissionId",b"_userPermissionId"]) -> typing.Optional[typing_extensions.Literal["userPermissionId"]]: ...
global___DataRoomValidationError = DataRoomValidationError

class PublishDatasetToDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATASETHASH_FIELD_NUMBER: builtins.int
    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFNAME_FIELD_NUMBER: builtins.int
    ENCRYPTIONKEY_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    datasetHash: builtins.bytes = ...
    dataRoomId: builtins.bytes = ...
    leafName: typing.Text = ...
    encryptionKey: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        datasetHash : builtins.bytes = ...,
        dataRoomId : builtins.bytes = ...,
        leafName : typing.Text = ...,
        encryptionKey : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"datasetHash",b"datasetHash",u"encryptionKey",b"encryptionKey",u"leafName",b"leafName",u"scope",b"scope"]) -> None: ...
global___PublishDatasetToDataRoomRequest = PublishDatasetToDataRoomRequest

class PublishDatasetToDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___PublishDatasetToDataRoomResponse = PublishDatasetToDataRoomResponse

class ExecuteComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    COMPUTENODENAMES_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    @property
    def computeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    isDryRun: builtins.bool = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        computeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        isDryRun : builtins.bool = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeNames",b"computeNodeNames",u"dataRoomId",b"dataRoomId",u"isDryRun",b"isDryRun",u"scope",b"scope"]) -> None: ...
global___ExecuteComputeRequest = ExecuteComputeRequest

class ExecuteDevelopmentComputeRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIGURATIONCOMMITID_FIELD_NUMBER: builtins.int
    COMPUTENODENAMES_FIELD_NUMBER: builtins.int
    ISDRYRUN_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    configurationCommitId: builtins.bytes = ...
    @property
    def computeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    isDryRun: builtins.bool = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        configurationCommitId : builtins.bytes = ...,
        computeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        isDryRun : builtins.bool = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeNames",b"computeNodeNames",u"configurationCommitId",b"configurationCommitId",u"isDryRun",b"isDryRun",u"scope",b"scope"]) -> None: ...
global___ExecuteDevelopmentComputeRequest = ExecuteDevelopmentComputeRequest

class ExecuteComputeResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___ExecuteComputeResponse = ExecuteComputeResponse

class JobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"jobId",b"jobId"]) -> None: ...
global___JobStatusRequest = JobStatusRequest

class JobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMPLETECOMPUTENODENAMES_FIELD_NUMBER: builtins.int
    @property
    def completeComputeNodeNames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        completeComputeNodeNames : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"completeComputeNodeNames",b"completeComputeNodeNames"]) -> None: ...
global___JobStatusResponse = JobStatusResponse

class GetResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    JOBID_FIELD_NUMBER: builtins.int
    COMPUTENODENAME_FIELD_NUMBER: builtins.int
    jobId: builtins.bytes = ...
    computeNodeName: typing.Text = ...
    def __init__(self,
        *,
        jobId : builtins.bytes = ...,
        computeNodeName : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"computeNodeName",b"computeNodeName",u"jobId",b"jobId"]) -> None: ...
global___GetResultsRequest = GetResultsRequest

class GetResultsResponseChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATA_FIELD_NUMBER: builtins.int
    data: builtins.bytes = ...
    def __init__(self,
        *,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> None: ...
global___GetResultsResponseChunk = GetResultsResponseChunk

class GetResultsResponseFooter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___GetResultsResponseFooter = GetResultsResponseFooter

class RetrieveDataRoomRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId"]) -> None: ...
global___RetrieveDataRoomRequest = RetrieveDataRoomRequest

class RetrieveDataRoomResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOM_FIELD_NUMBER: builtins.int
    @property
    def dataRoom(self) -> data_room_pb2.DataRoom: ...
    def __init__(self,
        *,
        dataRoom : typing.Optional[data_room_pb2.DataRoom] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoom",b"dataRoom"]) -> None: ...
global___RetrieveDataRoomResponse = RetrieveDataRoomResponse

class RetrieveAuditLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrieveAuditLogRequest = RetrieveAuditLogRequest

class RetrieveAuditLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LOG_FIELD_NUMBER: builtins.int
    log: builtins.bytes = ...
    def __init__(self,
        *,
        log : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"log",b"log"]) -> None: ...
global___RetrieveAuditLogResponse = RetrieveAuditLogResponse

class RetrieveDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrieveDataRoomStatusRequest = RetrieveDataRoomStatusRequest

class RetrieveDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    status: global___DataRoomStatus.V = ...
    def __init__(self,
        *,
        status : global___DataRoomStatus.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"status",b"status"]) -> None: ...
global___RetrieveDataRoomStatusResponse = RetrieveDataRoomStatusResponse

class UpdateDataRoomStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    status: global___DataRoomStatus.V = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        status : global___DataRoomStatus.V = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope",u"status",b"status"]) -> None: ...
global___UpdateDataRoomStatusRequest = UpdateDataRoomStatusRequest

class UpdateDataRoomStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___UpdateDataRoomStatusResponse = UpdateDataRoomStatusResponse

class RetrievePublishedDatasetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"scope",b"scope"]) -> None: ...
global___RetrievePublishedDatasetsRequest = RetrievePublishedDatasetsRequest

class PublishedDataset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEAFNAME_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    DATASETHASH_FIELD_NUMBER: builtins.int
    leafName: typing.Text = ...
    user: typing.Text = ...
    timestamp: builtins.int = ...
    datasetHash: builtins.bytes = ...
    def __init__(self,
        *,
        leafName : typing.Text = ...,
        user : typing.Text = ...,
        timestamp : builtins.int = ...,
        datasetHash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"datasetHash",b"datasetHash",u"leafName",b"leafName",u"timestamp",b"timestamp",u"user",b"user"]) -> None: ...
global___PublishedDataset = PublishedDataset

class RetrievePublishedDatasetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PUBLISHEDDATASETS_FIELD_NUMBER: builtins.int
    @property
    def publishedDatasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublishedDataset]: ...
    def __init__(self,
        *,
        publishedDatasets : typing.Optional[typing.Iterable[global___PublishedDataset]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"publishedDatasets",b"publishedDatasets"]) -> None: ...
global___RetrievePublishedDatasetsResponse = RetrievePublishedDatasetsResponse

class RemovePublishedDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    LEAFNAME_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    leafName: typing.Text = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        leafName : typing.Text = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId",u"leafName",b"leafName",u"scope",b"scope"]) -> None: ...
global___RemovePublishedDatasetRequest = RemovePublishedDatasetRequest

class RemovePublishedDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___RemovePublishedDatasetResponse = RemovePublishedDatasetResponse

class CreateConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMIT_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commit : typing.Optional[data_room_pb2.ConfigurationCommit] = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit",b"commit",u"scope",b"scope"]) -> None: ...
global___CreateConfigurationCommitRequest = CreateConfigurationCommitRequest

class CreateConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId"]) -> None: ...
global___CreateConfigurationCommitResponse = CreateConfigurationCommitResponse

class GenerateMergeApprovalSignatureRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___GenerateMergeApprovalSignatureRequest = GenerateMergeApprovalSignatureRequest

class GenerateMergeApprovalSignatureResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SIGNATURE_FIELD_NUMBER: builtins.int
    signature: builtins.bytes = ...
    def __init__(self,
        *,
        signature : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"signature",b"signature"]) -> None: ...
global___GenerateMergeApprovalSignatureResponse = GenerateMergeApprovalSignatureResponse

class MergeConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class ApprovalSignaturesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        value: builtins.bytes = ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : builtins.bytes = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    COMMITID_FIELD_NUMBER: builtins.int
    APPROVALSIGNATURES_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    @property
    def approvalSignatures(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.bytes]: ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        approvalSignatures : typing.Optional[typing.Mapping[typing.Text, builtins.bytes]] = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"approvalSignatures",b"approvalSignatures",u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___MergeConfigurationCommitRequest = MergeConfigurationCommitRequest

class RetrieveDataRoomConfigurationHistoryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DATAROOMID_FIELD_NUMBER: builtins.int
    dataRoomId: builtins.bytes = ...
    def __init__(self,
        *,
        dataRoomId : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"dataRoomId",b"dataRoomId"]) -> None: ...
global___RetrieveDataRoomConfigurationHistoryRequest = RetrieveDataRoomConfigurationHistoryRequest

class RetrieveDataRoomConfigurationHistoryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CURRENTCONFIGURATION_FIELD_NUMBER: builtins.int
    CONFIGURATIONSHISTORY_FIELD_NUMBER: builtins.int
    PIN_FIELD_NUMBER: builtins.int
    @property
    def currentConfiguration(self) -> data_room_pb2.DataRoomConfiguration: ...
    @property
    def configurationsHistory(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...
    pin: builtins.bytes = ...
    def __init__(self,
        *,
        currentConfiguration : typing.Optional[data_room_pb2.DataRoomConfiguration] = ...,
        configurationsHistory : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        pin : builtins.bytes = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"currentConfiguration",b"currentConfiguration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"configurationsHistory",b"configurationsHistory",u"currentConfiguration",b"currentConfiguration",u"pin",b"pin"]) -> None: ...
global___RetrieveDataRoomConfigurationHistoryResponse = RetrieveDataRoomConfigurationHistoryResponse

class RetrieveConfigurationCommitApproversRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___RetrieveConfigurationCommitApproversRequest = RetrieveConfigurationCommitApproversRequest

class RetrieveConfigurationCommitApproversResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APPROVERS_FIELD_NUMBER: builtins.int
    @property
    def approvers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        approvers : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"approvers",b"approvers"]) -> None: ...
global___RetrieveConfigurationCommitApproversResponse = RetrieveConfigurationCommitApproversResponse

class RetrieveConfigurationCommitRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITID_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    commitId: builtins.bytes = ...
    scope: builtins.bytes = ...
    def __init__(self,
        *,
        commitId : builtins.bytes = ...,
        scope : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitId",b"commitId",u"scope",b"scope"]) -> None: ...
global___RetrieveConfigurationCommitRequest = RetrieveConfigurationCommitRequest

class RetrieveConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMIT_FIELD_NUMBER: builtins.int
    @property
    def commit(self) -> data_room_pb2.ConfigurationCommit: ...
    def __init__(self,
        *,
        commit : typing.Optional[data_room_pb2.ConfigurationCommit] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit",b"commit"]) -> None: ...
global___RetrieveConfigurationCommitResponse = RetrieveConfigurationCommitResponse

class MergeConfigurationCommitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___MergeConfigurationCommitResponse = MergeConfigurationCommitResponse

class DriverTaskConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NOOP_FIELD_NUMBER: builtins.int
    STATICCONTENT_FIELD_NUMBER: builtins.int
    @property
    def noop(self) -> global___NoopConfig: ...
    @property
    def staticContent(self) -> global___StaticContentConfig: ...
    def __init__(self,
        *,
        noop : typing.Optional[global___NoopConfig] = ...,
        staticContent : typing.Optional[global___StaticContentConfig] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"driver_task_config",b"driver_task_config",u"noop",b"noop",u"staticContent",b"staticContent"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"driver_task_config",b"driver_task_config",u"noop",b"noop",u"staticContent",b"staticContent"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"driver_task_config",b"driver_task_config"]) -> typing.Optional[typing_extensions.Literal["noop","staticContent"]]: ...
global___DriverTaskConfig = DriverTaskConfig

class NoopConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    def __init__(self,
        ) -> None: ...
global___NoopConfig = NoopConfig

class StaticContentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes = ...
    def __init__(self,
        *,
        content : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"content",b"content"]) -> None: ...
global___StaticContentConfig = StaticContentConfig
